betty.app.factory module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.app.factory module

Functionality for creating new instances of types that depend on `betty.app.App`.

class betty.app.factory.AppDependentFactory

  Bases: `ABC`

  Allow this type to be instantiated using a `betty.app.App`.

  abstractmethod async classmethod new_for_app(app: App) → Self

    Create a new instance using the given app.